# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-03-29 08:17
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('videos', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='album',
            old_name='description',
            new_name='short_description',
        ),
        migrations.AddField(
            model_name='album',
            name='full_description',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, max_length=10000, verbose_name='Full description'),
        ),
        migrations.AlterField(
            model_name='album',
            name='name',
            field=models.CharField(max_length=255, verbose_name="\u0406\u043c'\u044f"),
        ),
        migrations.AlterField(
            model_name='video',
            name='name',
            field=models.CharField(max_length=255, verbose_name="\u0406\u043c'\u044f"),
        ),
    ]
